pub struct TrustblockForwarder<M>(_);

Implementations

source

impl<M: Middleware> TrustblockForwarder<M>

source

pub fn new<T: Into<Address>>(address: T, client: Arc<M>) -> Self

Creates a new contract instance with the specified ethers client at address. The contract derefs to a ethers::Contract object.

source

pub fn eip712_domain_type(&self) -> ContractCall<M, String>

Calls the contract’s EIP712_DOMAIN_TYPE (0xc3f28abd) function

source

pub fn generic_params(&self) -> ContractCall<M, String>

Calls the contract’s GENERIC_PARAMS (0x066a310c) function

source

pub fn get_encoded( &self, req: ForwardRequest, request_type_hash: [u8; 32], suffix_data: Bytes ) -> ContractCall<M, Bytes>

Calls the contract’s _getEncoded (0xe2b62f2d) function

source

pub fn domains(&self, p0: [u8; 32]) -> ContractCall<M, bool>

Calls the contract’s domains (0xc722f177) function

source

pub fn execute( &self, req: ForwardRequest, domain_separator: [u8; 32], request_type_hash: [u8; 32], suffix_data: Bytes, sig: Bytes ) -> ContractCall<M, (bool, Bytes)>

Calls the contract’s execute (0xe024dc7f) function

source

pub fn get_nonce(&self, from: Address) -> ContractCall<M, U256>

Calls the contract’s getNonce (0x2d0335ab) function

source

pub fn owner(&self) -> ContractCall<M, Address>

Calls the contract’s owner (0x8da5cb5b) function

source

pub fn register_domain_separator( &self, name: String, version: String ) -> ContractCall<M, ()>

Calls the contract’s registerDomainSeparator (0x9c7b4592) function

source

pub fn register_request_type( &self, type_name: String, type_suffix: String ) -> ContractCall<M, ()>

Calls the contract’s registerRequestType (0xd9210be5) function

source

pub fn supports_interface(&self, interface_id: [u8; 4]) -> ContractCall<M, bool>

Calls the contract’s supportsInterface (0x01ffc9a7) function

source

pub fn transfer_ownership(&self, new_owner: Address) -> ContractCall<M, ()>

Calls the contract’s transferOwnership (0xf2fde38b) function

source

pub fn type_hashes(&self, p0: [u8; 32]) -> ContractCall<M, bool>

Calls the contract’s typeHashes (0x21fe98df) function

source

pub fn verify( &self, req: ForwardRequest, domain_separator: [u8; 32], request_type_hash: [u8; 32], suffix_data: Bytes, sig: Bytes ) -> ContractCall<M, ()>

Calls the contract’s verify (0xad9f99c7) function

source

pub fn domain_registered_filter( &self ) -> Event<Arc<M>, M, DomainRegisteredFilter>

Gets the contract’s DomainRegistered event

source

pub fn ownership_transferred_filter( &self ) -> Event<Arc<M>, M, OwnershipTransferredFilter>

Gets the contract’s OwnershipTransferred event

source

pub fn request_type_registered_filter( &self ) -> Event<Arc<M>, M, RequestTypeRegisteredFilter>

Gets the contract’s RequestTypeRegistered event

source

pub fn events(&self) -> Event<Arc<M>, M, TrustblockForwarderEvents>

Returns an Event builder for all the events of this contract.

Methods from Deref<Target = Contract<M>>

pub fn address(&self) -> H160

Returns the contract’s address

pub fn abi(&self) -> &Contract

Returns a reference to the contract’s ABI.

pub fn client(&self) -> Bwhere B: Clone,

Returns a pointer to the contract’s client.

pub fn client_ref(&self) -> &M

Returns a reference to the contract’s client.

pub fn connect<N>(&self, client: Arc<N>) -> ContractInstance<Arc<N>, N>where N: Middleware,

Returns a new contract instance using the provided client

Clones self internally

pub fn connect_with<C, N>(&self, client: C) -> ContractInstance<C, N>where C: Borrow<N>,

Returns a new contract instance using the provided client

Clones self internally

pub fn event_with_filter<D>(&self, filter: Filter) -> Event<B, M, D>where D: EthLogDecode,

Returns an Event builder with the provided filter.

pub fn event<D>(&self) -> Event<B, M, D>where D: EthEvent,

Returns an Event builder for the provided event.

pub fn event_for_name<D>(&self, name: &str) -> Result<Event<B, M, D>, Error>where D: EthLogDecode,

Returns an Event builder with the provided name.

pub fn method_hash<T, D>( &self, signature: [u8; 4], args: T ) -> Result<FunctionCall<B, M, D>, AbiError>where T: Tokenize, D: Detokenize,

Returns a transaction builder for the selected function signature. This should be preferred if there are overloaded functions in your smart contract

pub fn method<T, D>( &self, name: &str, args: T ) -> Result<FunctionCall<B, M, D>, AbiError>where T: Tokenize, D: Detokenize,

Returns a transaction builder for the provided function name. If there are multiple functions with the same name due to overloading, consider using the method_hash method instead, since this will use the first match.

pub fn at<T>(&self, address: T) -> ContractInstance<B, M>where T: Into<H160>,

Returns a new contract instance at address.

Clones self internally

Methods from Deref<Target = BaseContract>

pub fn encode<T>(&self, name: &str, args: T) -> Result<Bytes, AbiError>where T: Tokenize,

Returns the ABI encoded data for the provided function and arguments

If the function exists multiple times and you want to use one of the overloaded versions, consider using encode_with_selector

pub fn encode_with_selector<T>( &self, signature: [u8; 4], args: T ) -> Result<Bytes, AbiError>where T: Tokenize,

Returns the ABI encoded data for the provided function selector and arguments

pub fn decode<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_raw<T>( &self, name: &str, bytes: T ) -> Result<Vec<Token, Global>, AbiError>where T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_output<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_output_raw<T>( &self, name: &str, bytes: T ) -> Result<Vec<Token, Global>, AbiError>where T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_event<D>( &self, name: &str, topics: Vec<H256, Global>, data: Bytes ) -> Result<D, AbiError>where D: Detokenize,

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

pub fn decode_event_raw( &self, name: &str, topics: Vec<H256, Global>, data: Bytes ) -> Result<Vec<Token, Global>, AbiError>

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T ) -> Result<Vec<Token, Global>, AbiError>where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector<D, T>( &self, signature: [u8; 4], bytes: T ) -> Result<D, AbiError>where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

pub fn decode_input_raw<T>( &self, bytes: T ) -> Result<Vec<Token, Global>, AbiError>where T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_input<D, T>(&self, bytes: T) -> Result<D, AbiError>where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

pub fn decode_output_with_selector<D, T>( &self, signature: [u8; 4], bytes: T ) -> Result<D, AbiError>where D: Detokenize, T: AsRef<[u8]>,

Decode the provided ABI encoded bytes as the output of the provided function selector

pub fn decode_output_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T ) -> Result<Vec<Token, Global>, AbiError>where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a [Token] vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn abi(&self) -> &Contract

Returns a reference to the contract’s ABI